@@ -97,6 +97,7 @@ MainWindow::MainWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
     sourceTypeComboBox = x->get_widget<Gtk::ComboBox>("sourceTypeComboBox");
     notebook = x->get_widget<Gtk::Notebook>("notebook");
     showVolumeMetersCheckButton = x->get_widget<Gtk::CheckButton>("showVolumeMetersCheckButton");
+    hideUnavailableCardProfilesCheckButton = x->get_widget<Gtk::CheckButton>("hideUnavailableCardProfilesCheckButton");
 
     sinkInputTypeComboBox->set_active((int) showSinkInputType);
     sourceOutputTypeComboBox->set_active((int) showSourceOutputType);
@@ -108,6 +109,7 @@ MainWindow::MainWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
     sinkTypeComboBox->signal_changed().connect(sigc::mem_fun(*this, &MainWindow::onSinkTypeComboBoxChanged));
     sourceTypeComboBox->signal_changed().connect(sigc::mem_fun(*this, &MainWindow::onSourceTypeComboBoxChanged));
     showVolumeMetersCheckButton->signal_toggled().connect(sigc::mem_fun(*this, &MainWindow::onShowVolumeMetersCheckButtonToggled));
+    hideUnavailableCardProfilesCheckButton->signal_toggled().connect(sigc::mem_fun(*this, &MainWindow::onHideUnavailableCardProfilesCheckButtonToggled));
 
     auto event_controller_key = Gtk::EventControllerKey::create();
     event_controller_key->signal_key_pressed().connect(sigc::mem_fun(*this, &MainWindow::on_key_press_event), false);
@@ -130,6 +132,9 @@ MainWindow::MainWindow(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
         if (g_key_file_has_key(config, "window", "showVolumeMeters", NULL)) {
             showVolumeMetersCheckButton->set_active(g_key_file_get_boolean(config, "window", "showVolumeMeters", NULL));
         }
+        if (g_key_file_has_key(config, "window", "hideUnavailableCardProfiles", NULL)) {
+            hideUnavailableCardProfilesCheckButton->set_active(g_key_file_get_boolean(config, "window", "hideUnavailableCardProfiles", NULL));
+        }
 
         int default_width, default_height;
         get_default_size(default_width, default_height);
@@ -237,6 +242,7 @@ MainWindow::~MainWindow() {
     g_key_file_set_integer(config, "window", "sinkType", sinkTypeComboBox->get_active_row_number());
     g_key_file_set_integer(config, "window", "sourceType", sourceTypeComboBox->get_active_row_number());
     g_key_file_set_integer(config, "window", "showVolumeMeters", showVolumeMetersCheckButton->get_active());
+    g_key_file_set_integer(config, "window", "hideUnavailableCardProfiles", hideUnavailableCardProfilesCheckButton->get_active());
 
     gsize filelen;
     GError *err = NULL;
@@ -360,6 +366,8 @@ void MainWindow::updateCard(const pa_card_info &info) {
         cardsVBox->append(*w);
         w->unreference();
         w->index = info.index;
+        w->hideUnavailableProfiles = hideUnavailableCardProfilesCheckButton->get_active();
+        w->prepareMenu();
         is_new = true;
     }
 
@@ -402,7 +410,7 @@ void MainWindow::updateCard(const pa_card_info &info) {
 
     w->profiles.clear();
     for (std::set<pa_card_profile_info2>::iterator profileIt = profile_priorities.begin(); profileIt != profile_priorities.end(); ++profileIt) {
-        bool hasNo = false, hasOther = false;
+        bool hasNo = false, hasOther = false, available = true;
         std::map<Glib::ustring, PortInfo>::iterator portIt;
         Glib::ustring desc = profileIt->description;
 
@@ -419,13 +427,18 @@ void MainWindow::updateCard(const pa_card_info &info) {
                 break;
             }
         }
-        if (hasNo && !hasOther)
+        if (hasNo && !hasOther) {
             desc += _(" (unplugged)");
+            available = false;
+        }
 
-        if (!profileIt->available)
+        if (!profileIt->available) {
             desc += _(" (unavailable)");
+            available = false;
+        }
 
         w->profiles.push_back(std::pair<Glib::ustring, Glib::ustring>(profileIt->name, desc));
+        w->availableProfiles[profileIt->name] = available;
     }
 
     w->activeProfile = info.active_profile ? info.active_profile->name : "";
@@ -613,7 +626,7 @@ static void suspended_callback(pa_stream *s, void *userdata) {
     MainWindow *w = static_cast<MainWindow*>(userdata);
 
     if (pa_stream_is_suspended(s))
-        w->updateVolumeMeter(pa_stream_get_device_index(s), PA_INVALID_INDEX, -1);
+        w->updateVolumeMeter(pa_stream_get_device_index(s), pa_stream_get_monitor_stream(s), -1);
 }
 
 static void read_callback(pa_stream *s, size_t length, void *userdata) {
@@ -699,7 +712,7 @@ void MainWindow::createMonitorStreamForSinkInput(SinkInputWidget* w, uint32_t si
         w->peak = NULL;
     }
 
-    w->peak = createMonitorStreamForSource(sinkWidgets[sink_idx]->monitor_index, w->index);
+    w->peak = createMonitorStreamForSource(sinkWidgets[sink_idx]->monitor_index, w->index, true);
 }
 
 void MainWindow::updateSource(const pa_source_info &info) {
@@ -708,6 +721,7 @@ void MainWindow::updateSource(const pa_source_info &info) {
     const char *icon;
     std::map<uint32_t, CardWidget*>::iterator cw;
     std::set<pa_source_port_info,source_port_prio_compare> port_priorities;
+    SourceType type = info.monitor_of_sink != PA_INVALID_INDEX ? SOURCE_MONITOR : (info.flags & PA_SOURCE_HARDWARE ? SOURCE_HARDWARE : SOURCE_VIRTUAL);
 
     if (sourceWidgets.count(info.index))
         w = sourceWidgets[info.index];
@@ -723,7 +737,7 @@ void MainWindow::updateSource(const pa_source_info &info) {
         w->setVolumeMeterVisible(showVolumeMetersCheckButton->get_active());
 
         if (pa_context_get_server_protocol_version(get_context()) >= 13)
-            w->peak = createMonitorStreamForSource(info.index, -1, !!(info.flags & PA_SOURCE_NETWORK));
+            w->peak = createMonitorStreamForSource(info.index, -1, !!(info.flags & PA_SOURCE_NETWORK) || type == SOURCE_MONITOR);
     }
 
     w->updating = true;
@@ -731,7 +745,7 @@ void MainWindow::updateSource(const pa_source_info &info) {
     w->card_index = info.card;
     w->name = info.name;
     w->description = info.description;
-    w->type = info.monitor_of_sink != PA_INVALID_INDEX ? SOURCE_MONITOR : (info.flags & PA_SOURCE_HARDWARE ? SOURCE_HARDWARE : SOURCE_VIRTUAL);
+    w->type = type;
 
     w->boldNameLabel->set_text("");
     gchar *txt;
@@ -1077,13 +1091,15 @@ void MainWindow::updateDeviceInfo(const pa_ext_device_restore_info &info) {
 
 
 void MainWindow::updateVolumeMeter(uint32_t source_index, uint32_t sink_input_idx, double v) {
+    MinimalStreamWidget *sw = NULL;
 
     if (sink_input_idx != PA_INVALID_INDEX) {
         SinkInputWidget *w;
 
         if (sinkInputWidgets.count(sink_input_idx)) {
             w = sinkInputWidgets[sink_input_idx];
-            w->updatePeak(v);
+            sw = static_cast<MinimalStreamWidget*>(w);
+            goto done;
         }
 
     } else {
@@ -1091,22 +1107,38 @@ void MainWindow::updateVolumeMeter(uint32_t source_index, uint32_t sink_input_id
         for (std::map<uint32_t, SinkWidget*>::iterator i = sinkWidgets.begin(); i != sinkWidgets.end(); ++i) {
             SinkWidget* w = i->second;
 
-            if (w->monitor_index == source_index)
-                w->updatePeak(v);
+            if (w->monitor_index == source_index) {
+                sw = static_cast<MinimalStreamWidget*>(w);
+                goto done;
+            }
         }
 
         for (std::map<uint32_t, SourceWidget*>::iterator i = sourceWidgets.begin(); i != sourceWidgets.end(); ++i) {
             SourceWidget* w = i->second;
 
-            if (w->index == source_index)
-                w->updatePeak(v);
+            if (w->index == source_index) {
+                sw = static_cast<MinimalStreamWidget*>(w);
+                goto done;
+            }
         }
 
         for (std::map<uint32_t, SourceOutputWidget*>::iterator i = sourceOutputWidgets.begin(); i != sourceOutputWidgets.end(); ++i) {
             SourceOutputWidget* w = i->second;
 
-            if (w->sourceIndex() == source_index)
-                w->updatePeak(v);
+            if (w->sourceIndex() == source_index) {
+                sw = static_cast<MinimalStreamWidget*>(w);
+                goto done;
+            }
+        }
+    }
+
+done:
+    if (sw) {
+        if (v == -1) {
+            sw->decayToZero();
+        } else {
+            sw->stopDecay();
+            sw->updatePeak(v);
         }
     }
 }
@@ -1422,3 +1454,14 @@ void MainWindow::onShowVolumeMetersCheckButtonToggled() {
         sw->setVolumeMeterVisible(state);
     }
 }
+
+
+void MainWindow::onHideUnavailableCardProfilesCheckButtonToggled() {
+    bool state = hideUnavailableCardProfilesCheckButton->get_active();
+
+    for (std::map<uint32_t, CardWidget*>::iterator it = cardWidgets.begin() ; it != cardWidgets.end(); it++) {
+        CardWidget *cw = it->second;
+        cw->hideUnavailableProfiles = state;
+        cw->prepareMenu();
+    }
+}
