@@ -29,6 +29,10 @@ class MainWindow;
 #  include <pulse/ext-device-restore.h>
 #endif
 
+#ifdef HAVE_LIBCANBERRA
+#include <canberra.h>
+#endif
+
 #include <unordered_map>
 
 class CardWidget;
@@ -76,10 +80,10 @@ public:
     void setConnectingMessage(const char *string = NULL);
 
     Gtk::Notebook *notebook;
-    Gtk::VBox *streamsVBox, *recsVBox, *sinksVBox, *sourcesVBox, *cardsVBox;
+    Gtk::Box *streamsVBox, *recsVBox, *sinksVBox, *sourcesVBox, *cardsVBox;
     Gtk::Label *noStreamsLabel, *noRecsLabel, *noSinksLabel, *noSourcesLabel, *noCardsLabel, *connectingLabel;
     Gtk::ComboBox *sinkInputTypeComboBox, *sourceOutputTypeComboBox, *sinkTypeComboBox, *sourceTypeComboBox;
-    Gtk::CheckButton *showVolumeMetersCheckButton;
+    Gtk::CheckButton *showVolumeMetersCheckButton, *hideUnavailableCardProfilesCheckButton;
 
     std::map<uint32_t, CardWidget*> cardWidgets;
     std::map<uint32_t, SinkWidget*> sinkWidgets;
@@ -98,6 +102,7 @@ public:
     virtual void onSinkTypeComboBoxChanged();
     virtual void onSourceTypeComboBoxChanged();
     virtual void onShowVolumeMetersCheckButtonToggled();
+    virtual void onHideUnavailableCardProfilesCheckButtonToggled();
 
     void setConnectionState(gboolean connected);
     void updateDeviceVisibility();
@@ -116,9 +121,13 @@ public:
 
     bool canRenameDevices;
 
+#ifdef HAVE_LIBCANBERRA
+    ca_context *canberraContext;
+#endif
+
 protected:
     virtual void on_realize();
-    virtual bool on_key_press_event(GdkEventKey* event);
+    virtual bool on_key_press_event(guint keyval, guint keycode, Gdk::ModifierType state);
 
 private:
     gboolean m_connected;
