@@ -21,17 +21,27 @@
 #ifndef minimalstreamwidget_h
 #define minimalstreamwidget_h
 
-#include "pavucontrol.h"
+#include <gtkmm.h>
+#include <pulse/pulseaudio.h>
 
-class MinimalStreamWidget : public Gtk::VBox {
+#define PEAKS_RATE 144
+#define DECAY_STEP (1.0 / PEAKS_RATE)
+
+class MinimalStreamWidget : public Gtk::Box {
 public:
-    MinimalStreamWidget(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& x);
+    MinimalStreamWidget(BaseObjectType* cobject);
+    virtual ~MinimalStreamWidget();
 
-    Gtk::VBox *channelsVBox;
+    /* Subclass constructors are expected to initialize these variables.
+     * MinimalStreamWidget can't initialize these, because the glade object
+     * id's depend on the subclass type. */
+    Gtk::Box *channelsVBox;
     Gtk::Label *nameLabel, *boldNameLabel;
     Gtk::Image *iconImage;
+
     Gtk::ProgressBar peakProgressBar;
     double lastPeak;
+    pa_stream *peak;
 
     bool updating;
 
@@ -41,7 +51,22 @@ public:
 
     bool volumeMeterEnabled;
     void enableVolumeMeter();
-    void updatePeak(double v);
+    void updatePeak(double v, double decayStep = DECAY_STEP);
+    void setVolumeMeterVisible(bool v);
+
+    void decayToZero();
+    void stopDecay();
+
+protected:
+    /* Subclasses must call this after the constructor to finalize the initial
+     * layout. */
+    void init();
+    bool decayOnTick(const Glib::RefPtr<Gdk::FrameClock>& frame_clock);
+
+private :
+    bool volumeMeterVisible;
+    guint decayTickId;
+    gint64 decayLastFrameTime;
 };
 
 #endif
