@@ -23,20 +23,14 @@
 
 #include <string>
 
-#include <signal.h>
-#include <string.h>
-
 #include <libintl.h>
 
 #include <gtkmm.h>
+#include <gtkmm/buildable.h>
 
 #include <pulse/pulseaudio.h>
 #include <pulse/glib-mainloop.h>
 
-#ifndef GLADE_FILE
-#define GLADE_FILE "pavucontrol.glade"
-#endif
-
 /* Can be removed when PulseAudio 0.9.23 or newer is required */
 #ifndef PA_VOLUME_UI_MAX
 # define PA_VOLUME_UI_MAX (pa_sw_volume_from_dB(+11.0))
@@ -74,7 +68,7 @@ enum SourceType {
 #include "mainwindow.h"
 
 pa_context* get_context(void);
-void show_error(const char *txt);
+void show_error(Gtk::Widget *w, const char *txt);
 
 MainWindow* pavucontrol_get_window(pa_glib_mainloop *m, bool maximize, bool retry, int tab_number);
 
